@@ -50,18 +50,22 @@ class Model:
             self.pipe = self.pipe.to("cuda")
         
         self.pipe.safety_checker = dummy
-        self.make_output_folder()
+        self.make_output_folders()
         if mac:
             self.warmup_pass()
 
     def warmup_pass(self):
         _ = self.pipe("nothing", num_inference_steps=1) # warmup to fix first-inference bug
 
-    def make_output_folder(self):
-        print("Creating output folder")
-        dir = path.join(getcwd(), f'./{self.skin_output_folder}')
-        if not path.isdir(dir):
-            mkdir(dir)
+    def make_output_folders(self):
+        output_folders = [
+            path.join(getcwd(), f'./{self.skin_output_folder}'),
+            path.join(getcwd(), f'./{self.cape_output_folder}')
+        ]
+        print(f"Creating {len(output_folders)} output folders")
+        for path in output_folders:
+            if not path.isdir(dir):
+                mkdir(dir)
 
     def pipeline_args(self, infer_config: InferConfig):
         args = {
@@ -93,6 +97,7 @@ class Model:
         prompts = infer_config.prompts
         generated_filenames = []
         try:
+            print(f"Inference config: {infer_config}")
             if any(profanity_predict(prompts)):
                 raise ProfanityError
             for idx, prompt in enumerate(prompts):
@@ -100,15 +105,15 @@ class Model:
                 tokened_prompt = f"{prompt} mc" if infer_config.creation_type is "SKIN" else f"{prompt}, sjh style"
                 images: List[Image.Image] = self.pipe(tokened_prompt, **self.pipeline_args(infer_config=infer_config)).images
                 filename = self.create_filename(prompt=prompt)
-                print(f"Images: {images}")
-                if infer_config.creation_type is "SKIN":
+                print(f"Generated images: {images}")
+                if infer_config.creation_type == "SKIN":
                     for image in images:
                         resized = image.resize((64, 64), resample=Image.Resampling.NEAREST)
                         cleaned = clean_skin(resized)
                         final_filename = f"./{self.skin_output_folder}/{filename}_resized.png"
                         cleaned.save(final_filename)
                         generated_filenames.append(final_filename)
-                elif infer_config.creation_type is "CAPE":
+                elif infer_config.creation_type == "CAPE":
                     print(f"Making a cape")
                     for image in images:
                         final_filename = f"./{self.cape_output_folder}/{filename}.png"
